==> risk-engine-api-0.1.5-20190219.013234-1-sources.jar: cn/com/duiba/tuia/risk/engine/api/rsp/ov/Blacklist.java <==
package cn.com.duiba.tuia.risk.engine.api.rsp.ov;


import java.io.Serializable;

public class Blacklist implements Serializable {

    private static final long serialVersionUID = -7627313517056051279L;

    private Long id;
    private Integer riskRank;
    private Integer dimension;
    private String val;
    private Integer stat;
    private Integer blacklistScene; //名单场景 0-推啊广告曝光场景 1-兑吧提现场景
    private String src;
    private String memo;
    private String creator;

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getRiskRank() {
        return riskRank;
    }

    public void setRiskRank(Integer riskRank) {
        this.riskRank = riskRank;
    }

    public Integer getDimension() {
        return dimension;
    }

    public void setDimension(Integer dimension) {
        this.dimension = dimension;
    }

    public Integer getStat() {
        return stat;
    }

    public void setStat(Integer stat) {
        this.stat = stat;
    }

    public String getVal() {
        return val;
    }

    public void setVal(String val) {
        this.val = val;
    }

    public String getSrc() {
        return src;
    }

    public void setSrc(String src) {
        this.src = src;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getUK() {
        return this.getBlacklistScene() + ":" + this.getDimension() + ":" + this.getVal();
    }

    public Integer getBlacklistScene() {
        return blacklistScene;
    }

    public void setBlacklistScene(Integer blacklistScene) {
        this.blacklistScene = blacklistScene;
    }

    @Override
    public String toString() {
        return "Blacklist{" +
                "id=" + id +
                ", riskRank=" + riskRank +
                ", dimension=" + dimension +
                ", val='" + val + '\'' +
                ", stat=" + stat +
                ", blacklistScene=" + blacklistScene +
                ", src='" + src + '\'' +
                ", memo='" + memo + '\'' +
                ", creator='" + creator + '\'' +
                '}';
    }
}

==> risk-engine-api-0.1.12-sources.jar: cn/com/duiba/tuia/risk/engine/api/rsp/ov/Blacklist.java <==
package cn.com.duiba.tuia.risk.engine.api.rsp.ov;


import java.io.Serializable;

public class Blacklist implements Serializable {

    private static final long serialVersionUID = -7627313517056051279L;

    private Long id;
    private Integer riskRank;
    private Integer dimension;
    private String val;
    private Integer stat;
    private Integer blacklistScene; //名单场景 0-推啊广告曝光场景 1-兑吧提现场景
    private String src;
    private String memo;
    private String creator;

    //硬件标示
    private String hardWare;

    //硬件标示加密
    private String hardWareMd5;

    //硬件标示类型
    private String hardWareType;

    //udid
    private String udid;

    //洗白原因
    private String washWhiteReason;

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getRiskRank() {
        return riskRank;
    }

    public void setRiskRank(Integer riskRank) {
        this.riskRank = riskRank;
    }

    public Integer getDimension() {
        return dimension;
    }

    public void setDimension(Integer dimension) {
        this.dimension = dimension;
    }

    public Integer getStat() {
        return stat;
    }

    public void setStat(Integer stat) {
        this.stat = stat;
    }

    public String getVal() {
        return val;
    }

    public void setVal(String val) {
        this.val = val;
    }

    public String getSrc() {
        return src;
    }

    public void setSrc(String src) {
        this.src = src;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getUK() {
        return this.getBlacklistScene() + ":" + this.getDimension() + ":" + this.getVal();
    }

    public Integer getBlacklistScene() {
        return blacklistScene;
    }

    public void setBlacklistScene(Integer blacklistScene) {
        this.blacklistScene = blacklistScene;
    }

    public String getHardWare() {
        return hardWare;
    }

    public void setHardWare(String hardWare) {
        this.hardWare = hardWare;
    }

    public String getHardWareMd5() {
        return hardWareMd5;
    }

    public void setHardWareMd5(String hardWareMd5) {
        this.hardWareMd5 = hardWareMd5;
    }

    public String getHardWareType() {
        return hardWareType;
    }

    public void setHardWareType(String hardWareType) {
        this.hardWareType = hardWareType;
    }

    public String getUdid() {
        return udid;
    }

    public void setUdid(String udid) {
        this.udid = udid;
    }

    public String getWashWhiteReason() {
        return washWhiteReason;
    }

    public void setWashWhiteReason(String washWhiteReason) {
        this.washWhiteReason = washWhiteReason;
    }

    @Override
    public String toString() {
        return "Blacklist{" +
                "id=" + id +
                ", riskRank=" + riskRank +
                ", dimension=" + dimension +
                ", val='" + val + '\'' +
                ", stat=" + stat +
                ", blacklistScene=" + blacklistScene +
                ", src='" + src + '\'' +
                ", memo='" + memo + '\'' +
                ", creator='" + creator + '\'' +
                ", hardWare='" + hardWare + '\'' +
                ", hardWareMd5='" + hardWareMd5 + '\'' +
                ", hardWareType='" + hardWareType + '\'' +
                ", udid='" + udid + '\'' +
                ", washWhiteReason='" + washWhiteReason + '\'' +
                '}';
    }
}
